function [yc,tc,nPeriods]=cropperiods(y,t,f)
  
# [yc, tc, nPeriods] = cropperiods(y, t, f)
#
# Crops the vector y to a length corresponding to the greatest available integer 
# number of periods of the frequency f. Vector t must have a size equal to that 
# of y and contain time coordinates of the samples contained therein.
#
# The cropped copy of vector y is returned in yc and the corresponding timing 
# vector is returned in tc. The number of periods included in yc and tc is 
# returned in nPeriods.

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  [torg,tsample] = sampledinterval(t);
  nPeriods = floor((torg+0.5*tsample)*f);
  tcropped = nPeriods / f;
  tend = t(1) + tcropped;
  iSpl = 0;
  norg = length(t);
  while (t(++iSpl) < tend && iSpl<norg), endwhile
  if (iSpl == norg)
    iSpl++;
  endif
  iSpl--;
  yc = y(1:iSpl);
  tc = t(1:iSpl);
  
endfunction
